!!! note
    These widgets are composed through a combination of [selector](selectors.md) and [input](input.md) widgets. To fully understand the picker functionality, it is recommended to read aforementioned pages.

!!! info
    All widgets have a `.mini` CSS class which you can assign to these widgets, to convert them to a single line.

---

## DatePicker

```{.textual path="docs/examples/screenshot/date_picker_example.py"}

```

::: textual_timepiece.pickers.DatePicker

---

## DurationPicker

```{.textual path="docs/examples/screenshot/duration_picker_example.py"}

```

::: textual_timepiece.pickers.DurationPicker

---

## TimePicker

```{.textual path="docs/examples/screenshot/time_picker_example.py"}

```

::: textual_timepiece.pickers.TimePicker

---

## DateTimePicker

```{.textual path="docs/examples/screenshot/datetime_picker_example.py"}

```

::: textual_timepiece.pickers.DateTimePicker

---

## DateRangePicker

```{.textual path="docs/examples/screenshot/date_range_picker_example.py"}

```

::: textual_timepiece.pickers.DateRangePicker

---

## DateTimeRangePicker

```{.textual path="docs/examples/screenshot/datetime_range_picker_example.py"}

```

::: textual_timepiece.pickers.DateTimeRangePicker

---

## DateTimeDurationPicker

```{.textual path="docs/examples/screenshot/datetime_duration_picker_example.py"}

```

::: textual_timepiece.pickers.DateTimeDurationPicker
